@@ -138,74 +138,42 @@ do support the tentmaker, which I hope you don't need to work on.
 
 The tree continues with the other child.  First I will show a simple outline
 of the whole tree as generated by outliner a script in the lib/Bigtop/Docs
-directory of the distribution.  Then I will show it again with discussion.
+directory of the distribution.  I've compressed the output of outliner
+to compress the tree vertically.  This means that attributes which are
+not themselves AST nodes are listed in line with their parent.
+
+Below the summary, I will show it again with discussion.  Note that in
+both the summary and the full discussion, nodes appear in logical order
+as they normally would in a Bigtop source file (modulo placing rare nodes
+near the bottom).  This is not the same order as the productions in the
+grammar.
 
 In summary:
 
-    application
-        __NAME__
-        __BODY__
-            block(s?)
-                literal_block
-                    __IDENT__
-                    __BACKEND__
-                    __BODY__
-                controller_block
-                    __IDENT__
-                    __NAME__
-                    __TYPE__
-                    __BODY__
-                        controller_method
-                            __IDENT__
-                            __NAME__
-                            __TYPE__
-                            __BODY__
-                                method_body
-                                    __KEYWORD__
-                                    __ARGS__
-                        controller_config_block
-                            __BODY__
-                                __KEYWORD__
-                                __ARGS__
-                        controller_literal_block
-                            __IDENT__
-                            __BACKEND__
-                            __BODY__
-                        controller_statement
-                            __KEYWORD__
-                            __ARGS__
-                table_block
-                    __IDENT__
-                    __NAME__
-                    __TYPE__
-                    __BODY__
-                        __IDENT__
-                        __NAME__
-                        __ARGS__
-                        __TYPE__
-                        __BODY__
-                            __KEYWORD__
-                            __DEF__
-                                __ARGS__
-                seq_block
-                    __IDENT__
-                    __NAME__
-                    __TYPE__
-                    __BODY__
-                join_table
-                    __IDENT__
-                    __NAME__
-                    __BODY__
+    application __NAME__ __BODY__:
+        block(s?):
+            app_config_block __BODY__:
+                app_config_statement __KEYWORD__ __ARGS__
+            app_statement __KEYWORD__ __ARGS__
+            table_block __IDENT__ __NAME__ __TYPE__ __BODY__:
+                __IDENT__ __NAME__ __ARGS__ __TYPE__ __BODY__:
+                    field_statement __KEYWORD__ __DEF__:
+                        field_statement_def __ARGS__
+            controller_block __IDENT__ __NAME__ __TYPE__ __BODY__:
+                controller_method __IDENT__ __NAME__ __TYPE__ __BODY__:
+                    method_body:
                         __KEYWORD__
-                        __DEF__
-                app_config_block
-                    __BODY__
-                        app_config_statement
-                            __KEY__
-                            __ARGS__
-                app_statement
+                        __ARGS__
+                controller_config_block __BODY__:
+                    controller_config_statement __KEYWORD__ __ARGS__
+                controller_literal_block __IDENT__ __BACKEND__ __BODY__
+                controller_statement __KEYWORD__ __ARGS__
+            join_table __IDENT__ __NAME__ __BODY__:
+                join_table_statement
                     __KEYWORD__
-                    __ARGS__
+                    __DEF__
+            literal_block __IDENT__ __BACKEND__ __BODY__
+            seq_block __IDENT__ __NAME__ __TYPE__ __BODY__
 
 =over 4
 
@@ -244,47 +212,141 @@ _statement.  These children are:
 
 =over 4
 
-=item literal_block
+=item app_statement
 
-This is a leaf node.  It responds to one highly useful method: make_output.
-Backends call it on the current subtree (remember it's a leaf) passing in
-their backend type.  If the current literal block has the same type, the
-text of the backquoted string in the Bigtop file is returned.  (A trailing
-new line is added to the user's input unless that input already had
-trailing whitespace.)  If the current node is of a different type, undef
-is returned.
+Represents a simple statement at the app level.  Has two keys:
 
-There is an optional additional parameter: want_hash.  Pass a true
-value if you need the output as
+=over 4
 
-    [ { $backend_type => $output } ]
+=item __KEYWORD__
 
-instead of the default:
+The statement's keyword (like authors).
 
-    [ $output ]
+=item __ARGS__
 
-This is useful if your backend handles multiple literal blocks in
-different ways.  For example, PerlTop and PerlBlock literals are
-both handled by Bigtop::Backend::Gantry::HttpdConf.  It needs the hash form
-to know where to put the literal output.
+An arg_list (see below).
 
-literal_blocks have three attributes:
+=back
+
+=item app_config_block
+
+Represents an app level config block.  Has one child:
+
+=over 4
+
+=item __BODY__
+
+An array (possibly undef) of objects blessed into:
+
+=over 4
+
+=item app_config_statement
+
+Has two attributes:
+
+=over 4
+
+=item __KEYWORD__
+
+The name of the set var.
+
+=item __ARGS__
+
+An arg_list (see below).
+
+=back
+
+=back
+
+=back
+
+=item table_block
+
+Responds to get_name which returns the name of the block's table.
+The attributes of a table node are:
 
 =over 4
 
 =item __IDENT__
 
-Internal unchanging name.
+The internal and unchanging name of the node.
 
-=item __BACKEND__
+=item __NAME__
 
-The name of the backend this literal is intended for.
+The name of the constructed sequence or table.
+
+=item __TYPE__
+
+As string, either sequences or tables.
 
 =item __BODY__
 
-The literal text for the backend.
+The body of the block.  This is an array (ref) of nodes blessed into:
 
-Usually it is easier to call make_output than to fish for these.
+=over 4
+
+=item table_element_block
+
+There are two types of these: statements and field blocks.
+Both are blessed into the table_element_block class.  They have the following
+keys:
+
+=over 4
+
+=item __IDENT__
+
+For field blocks only.  The internal and unchanging name of the node.
+
+=item __NAME__
+
+For field blocks only.  The name of the field (and its SQL column).
+
+=item __ARGS__
+
+For statements only, the arguments of the statement.  This is an arg_list,
+see below.
+
+=item __TYPE__
+
+Either 'field' for field blocks or the statement keyword for statements.
+
+=item __BODY__
+
+Either the statement keyword for statements, or an array (ref) of nodes
+blessed into:
+
+=over 4
+
+=item field_statement
+
+The class for field blocks.  These nodes have the following keys:
+
+=over 4
+
+=item __KEYWORD__
+
+The keyword of the statement.
+
+=item __DEF__
+
+A node blessed into the field_statement_def package, which has a single
+key:
+
+=over 4
+
+=item __ARGS__
+
+An arg list, see below.
+
+=back
+
+=back
+
+=back
+
+=back
+
+=back
 
 =back
 
@@ -393,8 +455,13 @@ Has a single key:
 
 =item __BODY__
 
-An array (ref) of nodes blessed into the controller_config_statement class,
-each of which is a leaf with two attributes:
+An array (ref) of nodes blessed into:
+
+=over 4
+
+=item controller_config_statement
+
+Each of these is a leaf with two attributes:
 
 =over 4
 
@@ -410,6 +477,8 @@ An arg_list (see below).
 
 =back
 
+=back
+
 =item controller_literal_block
 
 This is really a statement, not a block (the name stuck before I decided
@@ -463,79 +532,95 @@ An arg list (see below).  This is optional and may therefore be undef.
 
 =back
 
-=item table_block
+=item join_table
 
-Responds to get_name which returns the name of the block's table.
-The attributes of a table node are:
+Represents a many-to-many relationship between two tables and the implicit
+table which goes between them.  Has three keys:
 
 =over 4
 
 =item __IDENT__
 
-The internal and unchanging name of the node.
+The internal invariant name of the block.  These are used by tentmaker
+to make updates to the existing tree and may vary from parse to parse.
 
 =item __NAME__
 
-The name of the constructed sequence or table.
-
-=item __TYPE__
-
-As string, either sequences or tables.
+The name of the implicit table.  The SQL backend will make SQL statements
+to generate this table in the schema.
 
 =item __BODY__
 
-The body of the block.  This is an array (ref) of table_element_block
-nodes.  There are two types of these: statements and field blocks.
-Both are blessed into the table_element_block class.  They have the following
-keys:
+An array (ref) of statements in the block.  There must be a joins statement.
+There may be an optional names statement.  Each array element blessed
+into:
 
 =over 4
 
-=item __IDENT__
+=item join_table_statement
 
-For field blocks only.  The internal and unchanging name of the node.
-
-=item __NAME__
-
-For field blocks only.  The name of the field (and its SQL column).
-
-=item __ARGS__
-
-For statements only, the arguments of the statement.  This is an arg_list,
-see below.
-
-=item __TYPE__
-
-Either 'field' for field blocks or the statement keyword for statements.
-
-=item __BODY__
-
-Either the statement keyword for statements, or an array (ref) of nodes
-blessed into the field_statement class for field blocks.  These nodes
-have the following keys:
+These are somewhat like field_statements, but they are simpler since both
+legal statements expect exactly one pair.
 
 =over 4
 
 =item __KEYWORD__
 
-The keyword of the statement.
+The statement keyword, must be either joins or names.  Exactly one joins
+statement must be present (if the parse is valid).  At most one names statement
+may be present.  These rules are enforced by the backend.
 
 =item __DEF__
 
-A node blessed into the field_statement_def package, which has a single
-key:
+An arg_list containing a single pair.
+
+=back
+
+=back
+
+=back
+
+=item literal_block
+
+This is a leaf node.  It responds to one highly useful method: make_output.
+Backends call it on the current subtree (remember it's a leaf) passing in
+their backend type.  If the current literal block has the same type, the
+text of the backquoted string in the Bigtop file is returned.  (A trailing
+new line is added to the user's input unless that input already had
+trailing whitespace.)  If the current node is of a different type, undef
+is returned.
+
+There is an optional additional parameter: want_hash.  Pass a true
+value if you need the output as
+
+    [ { $backend_type => $output } ]
+
+instead of the default:
+
+    [ $output ]
+
+This is useful if your backend handles multiple literal blocks in
+different ways.  For example, PerlTop and PerlBlock literals are
+both handled by Bigtop::Backend::Gantry::HttpdConf.  It needs the hash form
+to know where to put the literal output.
+
+literal_blocks have three attributes:
 
 =over 4
 
-=item __ARGS__
+=item __IDENT__
 
-An arg list, see below.
+Internal unchanging name.
 
-=back
+=item __BACKEND__
 
-=back
+The name of the backend this literal is intended for.
 
-=back
+=item __BODY__
+
+The literal text for the backend.
+
+Usually it is easier to call make_output than to fish for these.
 
 =back
 
@@ -569,93 +654,6 @@ As it is, you can't use this.
 
 =back
 
-=item join_table
-
-Represents a many-to-many relationship between two tables and the implicit
-table which goes between them.  Has three keys:
-
-=over 4
-
-=item __IDENT__
-
-The internal invariant name of the block.  These are used by tentmaker
-to make updates to the existing tree and may vary from parse to parse.
-
-=item __NAME__
-
-The name of the implicit table.  The SQL backend will make SQL statements
-to generate this table in the schema.
-
-=item __BODY__
-
-An array (ref) of statements in the block.  There must be a joins statement.
-There may be an optional names statement.  Each array element blessed
-into the join_table_statement class which has these keys:
-
-=over 4
-
-=item __KEYWORD__
-
-The statement keyword, must be either joins or names.  Exactly one joins
-statement must be present (if the parse is valid).  At most one names statement
-may be present.  These rules are enforced by the backend.
-
-=item __DEF__
-
-An arg_list containing a single pair.
-
-=back
-
-=back
-
-=item app_config_block
-
-Represents an app level config block.  Has one child:
-
-=over 4
-
-=item __BODY__
-
-An array (possibly undef) of objects blessed into:
-
-=over 4
-
-=item app_config_statement
-
-Has two attributes:
-
-=over 4
-
-=item __KEY__
-
-The name of the set var.
-
-=item __ARGS__
-
-An arg_list (see below).
-
-=back
-
-=back
-
-=back
-
-=item app_statement
-
-Represents a simple statement at the app level.  Has two keys:
-
-=over 4
-
-=item __KEYWORD__
-
-The statement's keyword (like authors).
-
-=item __ARGS__
-
-An arg_list (see below).
-
-=back
-
 =back
 
 =back
