@@ -547,6 +547,15 @@ they understand.
                                         user.  See Data::FormValidator.
                                     </td>
                                 </tr>
+                                <tr>
+                                    <td valign='top'>
+                                        html_form_default_value
+                                    </td>
+                                    <td>
+                                        A literal to use when the user and
+                                        the database have provided a value.
+                                    </td>
+                                </tr>
                                 <tr>
                                     <td valign='top'>
                                         html_form_display_size
