@@ -176,28 +176,52 @@ rest is really just typing it in.
 
 When starting an app from scratch one might use a tool like h2xs to build
 diretory structures and standard files (like Changes).  This is a good
-idea with bigtop too.  Simply type:
+idea with bigtop too.  We could just run bigtop to make a default app:
 
-    bigtop --new Apps::Billing customers my_companies \
+    bigtop --new Billing
+
+But it can do a lot of initial work for us if we give some information
+about our data model.  That could be as simple as listing the tables:
+
+    bigtop -n Billing customers my_companies \
             invoices line_items status
 
-This will make the Apps-Billing subdirectory of the current directory.
-In it you will find many files including: Build.PL, Changes, MANIFEST,
-MANIFEST.SKIP, README plus directories: docs, html, lib, and t.  The
-directories will have lots of goodies, including: docs/schema.sqlite for
-building a quick test database with sqlite, html/genwrapper.tt a template
-toolkit wrapper providing a lavendar theme for the app, a set of models for
-the tables, and a set of controllers for those tables.  Finally, the docs
-directory will have apps-billing.bigtop, which will edit until it describes
-our app more correctly.
+But, we could go further and tell it about the foreign key relationships
+between the tables:
+
+    bigtop -n Billing 'customers<-invoices
+    invoices->status invoices->my_companies
+    line_items->customers line_items->invoices'
+
+Since this document started before the -n flag to arguments, the
+billing.bigtop file it describes will differ from yours if you use
+either of the -n versions above.  But, the differences are mainly in the
+order in which things appear.  For instance, when I typed in the file
+I chose to keep all the tables together and they come first.  Then
+the controllers follow as a group.  With -n each table/controller
+pair will appear in the order of first appearance of the table name
+on the command line.  There are other similar differences, but all of
+them are only cosmetic.  All the commands are the same and have the
+same effect, even if the order differs slightly.
+
+Any of the bigtop -n options above will make the Billing subdirectory of
+the current directory.  In it you will find many files including: Build.PL,
+Changes, MANIFEST, MANIFEST.SKIP, README plus directories: docs, html, lib,
+and t.  The directories will have lots of goodies, including:
+docs/schema.sqlite for building a quick test database with sqlite,
+html/genwrapper.tt a template toolkit wrapper providing a tan theme for the
+app, a set of models for the tables, and a set of controllers for those
+tables.  Finally, the docs directory will have billing.bigtop, which will
+edit until it describes our app more correctly.
 
 All the tables will have the same default columns: id, ident, description,
-created, and modified.
+created, and modified.  The ones on the tail end of a foreign key
+will also have a column for that foreign key.
 
 At this point, we could create the database and start the app.  But since
 the tables don't store our actual data, it is better to wait.
 
-We will now begin editing docs/apps-billing.bigtop.  After we edit it,
+We will now begin editing docs/billing.bigtop.  After we edit it,
 we will regenerate the app.  When you run bigtop to do that, you should
 be in the directory where the Changes file lives.  (If you aren't, it will
 not build for you without strong insistence.)
@@ -209,10 +233,9 @@ look like this:
     config {
         engine CGI;
         template_engine TT;
-        Init Std { no_gen 1; }
         # ...
     }
-    app Apps::Billing {
+    app Billing {
         # ...
     }
 
@@ -225,25 +248,33 @@ non-whitespace character is a pound sign is ignored as a comment.
 At the top of each bigtop file is a config section.  In it, we list a few
 properties of the app and what pieces bigtop should generate for us.
 
-The stub made with the --new option to bigtop has one block in it:
+With the --new option to bigtop the config section looks like this:
 
-    config {
-        engine          CGI;
-        template_engine TT;
+ config {
+     engine          CGI;
+     template_engine TT;
 
-        Init            Std             { no_gen 1; }
-        SQL             SQLite          {}
-        SQL             Postgres        {}
-        SQL             MySQL           {}
-        CGI             Gantry          { with_server 1; gen_root 1; }
-        Control         Gantry          { dbix 1; }
-        Model           GantryDBIxClass {}
-        SiteLook        GantryDefault   {}
-    }
+     Init      Std             { no_gen 1; }
+     SQL       SQLite          {}
+     SQL       Postgres        {}
+     SQL       MySQL           {}
+     CGI       Gantry          { with_server 1; gen_root 1; flex_db 1; }
+     Control   Gantry          { dbix 1; }
+     Model     GantryDBIxClass {}
+     SiteLook  GantryDefault   {}
+ }
+
+Note that billing.example does not have C<no_gen> for Init Std.  After
+you build it with
+
+    bigtop --create billing.bigtop
+
+you should set C<no_gen> as above so the Changes, README, etc. are not
+rewritten.
 
 First there are two statements.  They request the engine and template
 engine which will service the app.  This one will run under CGI (for
-the time being) and will rely on template toolkit for output formatting.
+the time being) and will rely on Template Toolkit for output formatting.
 When we are ready to move to mod_perl, we can simply change the engine,
 add a backend (HttpdConf Gantry), regenerate, and be ready to go.
 
@@ -271,7 +302,7 @@ on an app with a sqlite database, then migrate to one of the others
 for deployment.
 
 The other four backends each do a different thing (as indicated by their
-different types).  CGI Gantry makes a cgi script ready for immediate
+different types).  CGI Gantry makes a CGI script ready for immediate
 deployment to our cgi-bin directory.  Since with_server has a true
 value, it also makes a handy stand alone server we can use during initial
 development.  The gen_root statement adds a config param called root
@@ -286,13 +317,14 @@ So, from these examples, we've learned that the name of the backend has
 a type and an implementation name.  These can be anything, so long as
 there is a Bigtop::Backend::Type::ImplName in the C<@INC> path.  So, we
 have asked for Bigtop::Backend::Init::Std, Bigtop::Backend::SQL::SQLite,
-etc.
+etc.  There is some advice on building your own backend in
+Bigtop::Docs::Modules.
 
 =head3 Order is (somewhat) important
 
 Note that generation usually happens in the order listed.  So, if you type:
 
-    bigtop apps-billing.bigtop all
+    bigtop billing.bigtop all
 
 The generation order will be Init, SQL, ...
 
@@ -302,32 +334,27 @@ creation, since it builds the directories.
 This principle is true for the other sections of the bigtop file.  So, if
 order is important in the output, use that order in the bigtop file.
 
-p.s. If you typed bigtop apps-billing.bigtop all, you need to remove
-the lib/Apps subdiretory for the rest of the tutorial to go well.
-Bigtop does not overwrite files it thinks you will modify.
-
 =head2 app section
 
 The app section has this form:
 
-    app Apps::Billing {
-        #...
-    }
+ app Billing {
+     #...
+ }
 
 Everything shown below is inside the app block, but we will update
 things according to our billing app spec.  The name is the package
 name of the base controller and is also a prefix for all other modules.
 
     config {
-        dbconn `dbi:Pg:dbname=billing` => no_accessor;
-        dbuser `` => no_accessor;
+        dbconn `dbi:SQLite:dbname=app.db` => no_accessor;
         template_wrapper `genwrapper.tt` => no_accessor;
     }
 
 You can include any config parameters you like in the app level config block.
 The backends will move them into the proper place for app configuration.
 For example, the CGI Gantry backend will put them into a hash in the
-cgi script (and stand alone server).  The HttpdConf Gantry backend would
+CGI script (and stand alone server).  The HttpdConf Gantry backend would
 instead make them PerlSetVars.  Later we will see how to use Gantry::Conf,
 then the Config General backend will put them into a flat file readable
 by Config::General.
@@ -345,7 +372,7 @@ dbuser or dbpass, so bigtop doesn't generate them.)  Note that if dbuser
 or dbpass include any characters Perl wouldn't like in a variable name,
 you must backquote the string, as in:
 
-    dbpass `s!m0n`;
+    dbpass `s!m0n` => no_accessor;
 
 The other parameter is the name of the generated TT wrapper.  It lives
 in the html directory.
@@ -357,50 +384,38 @@ pieces: the data model and the controllers which manage it.
 
 We'll start with the data model.
 
-There are two basic blocks that describe that model: sequence and table.
-sequence defines a sequence and must come before the table that uses
-it (since the generated SQL is in the same order as the blocks in the
-bigtop file).
-
-Currently, sequence blocks must be empty.  Some day you may be
-able to control max and min values, etc. with statements in the blocks.
-
-    sequence customers_seq {}
-
-If your database does not understand sequences, they are silently ignored
-by the backend for your database.
+For this app there is one basic block that describe that model: table.
 
 Table blocks take this form:
 
     table name { ... }
 
 Inside the braces, you can include either statements or field blocks.  There
-are three legal statements.  One of them was supplied for us: sequence.
+are three legal statements.  One of them was supplied for us: foreign_display.
+It comes after the gernated fields.
 
-    table customers {
-        sequence        customers_seq;
+    table my_companies {
+        # ... generated fields
+        foriegn_display `%ident`;
 
-sequence associates a table with a sequence.
-
-We want to add foreign_display:
-
-        foreign_display `%name`;
+We want to change this from C<`%ident`> to C<`%name`>.
 
 This controls what is displayed when other tables refer to this one.  In
 this case, they will see the name of the company.  If there were people
-in a table, foreign_display might be %last, %first.  So, percent followed
+in a table, foreign_display might be C<`%last, %first`>.  So, percent followed
 by a column name will be replaced with the value of that column for each
 row.  Note that the percent sign in the value requires us to surround
 all foreign_display values with backquotes.
 
-We'll use the third statement in the status table below.
+We'll use the data statement in the status table below.  The third statement
+is useful only if you want to use Postgres sequences.
 
 The rest of the customers table is a set of field blocks.  Like other blocks,
 field blocks have this form:
 
     field name { ... }
 
-Inside, it is a list of statements.  Some of those shown below
+Inside is a list of statements.  Some of those shown below
 are specific to Gantry, in particular, many depend on its default
 templates.
 
@@ -414,36 +429,30 @@ means your database understands it).  You can provide a single keyword,
 a list of keywords, a backquoted string, or a comma separated combination
 of those.  Back quoted strings are taken literally.
 
+You may use the C<int4> type even if your database doesn't understand
+it.  Then the backend for your database will convert it into a reasonable
+integer type.  You may always choose to be explicit instead of relying
+on that magic.
+
 You should use the bare C<primary_key> as one attribute of the id column.
 This not only generates 'PRIMARY KEY' in the SQL output, but
 marks the column as primary for the ORM.
 
 There is a special keyword you may use to fill in the primary key by
-default: assign_by_sequence, which you may abbreviate as auto.  In postgres
-the above is equivalent to:
+default: C<auto>.  The SQL for this request varies by database, but
+all three supported databases work properly.
 
-    field id { is int4, primary_key, `DEFAULT NEXTVAL( 'mycomp_seq' )`; }
-
-Both of them generate this SQL:
-
-    id int4 PRIMARY KEY DEFAULT NEXTVAL( 'mycomp_seq' ),
-
-and they both mark id as the primary key for data modelers.  If your
-database doesn't understand sequences, your backend will generate something
-more like:
-
-    id int4 PRIMARY KEY AUTO-INCREMENT
-
-Note that primary_key, assign_by_key, and auto must be bare (not inside
+Note that primary_key and auto must be bare (not inside
 quotes).  Remember: backquoted strings are taken literally.
 
 Since ids rarely appear on screen, they usually only have an is statement.
 Other fields are shown to the user and thus have other statements.
 When bigtop makes a new app from a list of tables, it puts five columns in
-each table: id, ident, descr, created, and modified.  We talked about
-id above, and we don't need to change it.  The other fields are too
-generic for our billing app,  So we finally have a bit of work to do
-(other than adding the foreign_display).
+each table: id, ident, description, created, and modified.  If you included
+ASCII art table relationships, other fields will be generated to represent
+them.  We talked about id above, and we don't need to change it.  The other
+fields are too generic for our billing app.  So, we finally have a bit of
+work to do (other than changing the foreign_display).
 
 Here is what the generated ident field block looks like:
 
@@ -453,7 +462,7 @@ Here is what the generated ident field block looks like:
             html_form_type text;
         }
 
-The descr field looks just like it with the name changed.  The created
+The description field looks just like it with the name changed.  The created
 and modified fields are more like this:
 
         field created {
@@ -465,8 +474,8 @@ For now, we'll keep the created and modified fields (even though they
 aren't in the model as we originally drew it).  But, we won't do anything
 with them, so if you don't like them, delete them.
 
-We need to change this to match our ident to name and changes its label
-to Name.  We wanted a descr field, so we'll keep it.  But we don't want
+We need to change the name of the ident field to name and its label
+to Name.  We wanted a description field, so we'll keep it.  But we don't want
 to require it, so add an html_form_optional statement:
 
         field name {
@@ -474,16 +483,19 @@ to require it, so add an html_form_optional statement:
             label          Name;
             html_form_type text;
         }
-        field descr {
+        field description {
             is                 varchar;
             label              Description;
             html_form_type     text;
             html_form_optional 1;
         }
 
-I've also added some whitespace to make things look a little better.
+I've also added some whitespace to make things look a little better.  Any
+whitespace between the tokens is ignored by bigtop.  In fact, if you
+use tentmaker, all whitespace is normalized.  So, my extra internal
+spacing would be removed on any trip through tentmaker.
 
-To finish the customers table, we need to add the rest of the contact
+To finish the my_companies table, we need to add the rest of the contact
 information to it.  Simply copy the address field, paste it six times
 and change the field names and labels, until your customers table has these:
 
@@ -530,13 +542,13 @@ SQL type information
 
 =item label
 
-what the user sees on the screen as the column label in html tables where
+what the user sees on the screen as the column label in HTML tables where
 the field appears and next to the entry elements where values for it are
 entered.
 
 =item html_form_type
 
-the input type for this field when it appears in an html_form.
+the input type for this field when it appears in an HTML form.
 Current Gantry templates only understand select, text, and textarea.
 
 =item html_form_optional
@@ -550,9 +562,7 @@ field.
 
 The other tables are similar.
 
-    sequence customers_seq     {}
     table    customers         {
-        sequence invoices_seq;
         foreign_display `%name`;
 
         field id { is int4, primary_key, assign_by_sequence; }
@@ -581,7 +591,7 @@ The other tables are similar.
             label          Zip;
             html_form_type text;
         }
-        field descr {
+        field description {
             is                 varchar;
             label              Description;
             html_form_type     text;
@@ -623,7 +633,7 @@ table has a due date for the task it describes:
             html_form_type   text;
         }
 
-The date_select_text will appear as an html href link next to the entry
+The date_select_text will appear as an HTML href link next to the entry
 field for the date.  If the user clicks the link, a popup will display
 an intuitive calendar.  If the user clicks a date on the popup calendar,
 the text input box will be populated with that date.
@@ -636,31 +646,38 @@ For example, see the LineItem controller below.
             label            Name;
             html_form_type   text;
         }
-        field company_id {
-            is                 int;
+        field my_companies {
+            is                 int4;
             label              `My Company`;
             refers_to          my_companies;
             html_form_type     select;
         }
 
-If a column is a foreign key, use the refers_to statement to say which
-table it points to.  Note that it must point to the primary key of the
-other table and we generally assume that the key will be the unique
-id column.  Bigtop::SQL::Postgres does not currently (nor is it ever likely
+Because we used the -> notation when running bigtop originally, the
+foreign key fields are already present.  But here is how to add one
+manually: use the refers_to statement to say which table it points to.
+Note that it must point to the primary key of the other table and we
+generally assume that the key will be the unique id column.
+Bigtop::Backend::SQL::Postgres does not currently (nor is it ever likely
 to) generate genuine SQL foreign keys.  If you want foreign
 keys, and your database supports them, consider implementing your own SQL
 backend to generate the SQL code for them.
 
+Note that when we used bigtop, it chose the foreign key column names
+to match the foreign table names exactly.  Our original data model
+diagram used slightly different names.  If you want the bigtop file
+to match the picture, change the names of the foreign key fields.
+
 The Gantry html_form_type for foreign key columns is C<select> which
 allows the user to pick one item from a pull down list.
 
-        field customer_id {
+        field customers {
             is                 int;
             label              Customer;
             refers_to          customers;
             html_form_type     select;
         }
-        field invoice_id {
+        field invoices {
             is                 int;
             label              `Invoice Number`;
             refers_to          invoices;
@@ -685,14 +702,14 @@ allows the user to pick one item from a pull down list.
             html_form_cols     50;
         }
 
-You can affect the eventual appearance of the field on html forms with
+You can affect the eventual appearance of the field on HTML forms with
 various statements.  Here are two that affect textareas: html_form_rows
 and html_form_cols; take a wild guess at what they do.  There is one
 gotcha for text input boxes.  Since Template Toolkit uses a lot of magic
 while dereferencing, to set the size of a text input box use
 html_form_display_size.
 
-        field descr {
+        field description {
             is                 text;
             label              `Notes to Self`;
             html_form_type     textarea;
@@ -712,7 +729,7 @@ html_form_display_size.
             label              Number;
             html_form_type     text;
         }
-        field status_id {
+        field status {
             is                 int;
             label              Status;
             refers_to          status;
@@ -752,7 +769,7 @@ html_form_display_size.
             html_form_rows     4;
             html_form_cols     50;
         }
-        field descr {
+        field description {
             is                 text;
             label              `Notes to Self`;
             html_form_type     textarea;
@@ -761,10 +778,8 @@ html_form_display_size.
             html_form_cols     50;
         }
     }
-    sequence status_seq        {}
     table    status            {
-        sequence status_seq;
-        foreign_display `%name: %descr`;
+        foreign_display `%name: %description`;
 
         field id { is int4, primary_key, assign_by_sequence; }
         field name {
@@ -772,18 +787,18 @@ html_form_display_size.
             label          Name;
             html_form_type text;
         }
-        field descr {
+        field description {
             is             varchar;
             label          Description;
             html_form_type text;
         }
 
-        data name => `Working`, descr => `Work is in Progress, not billed`;
-        data name => `Sent`,    descr => `Mailed to Customer`;
-        data name => `Paid`,    descr => `Payment Received`;
+        data name => `Working`, description => `Work in Progress, not billed`;
+        data name => `Sent`,    description => `Mailed to Customer`;
+        data name => `Paid`,    description => `Payment Received`;
     }
 
-Here we see the final legal simple statement in a table block: data.
+Here we see another legal simple statement in a table block: data.
 Use it as many times as you need to make rows in the table.  In this case,
 we want statuses which the user could edit.  But, we want some good
 initial values.
@@ -805,14 +820,13 @@ As with tables, controllers are defined with a block:
     controller Name { ... }
 
 There is usually a controller for each table and that is the case in
-this sample.  The order is not usually important.  If you have a url
+this sample.  The order is not usually important.  If you have a URL
 heirarchy under mod_perl, it will matter, since the httpd.conf must
 list higher elements first.
 
-    controller Status {
+    controller Status is AutoCRUD {
         controls_table   status;
         rel_location     status;
-        uses             Gantry::Plugins::AutoCRUD;
         text_description status;
         page_link_label  Status;
         ...
@@ -837,12 +851,12 @@ rel_location with location.)
 =item uses
 
 This is a comma separated list of modules which should be used by the
-generated module.  Basically, this amounts to adding the following to
-the module's .pm file:
+generated modules.  Basically, this amounts to adding the following to
+the controller's stub and GEN modules:
 
-    use Gantry::Plugins::AutoCRUD;
+    use SomeModule;
 
-[ except that there are two generated modules and both will list all
+[ except that both use statements will list all
 of the default exports explicitly. ]
 
 =item text_description
@@ -857,23 +871,26 @@ navigation.
 
 =back
 
-Some of these could be assumed, but they are not.  One of our principles
-is explicit is better than implicit.
+When you supply tables to bigtop during initial app creation, or with
+the --add flag, most of these statements are used and given good
+default values based purely on the name of the table.  But, machine
+generated names often leave something to be desired, so you'll want to
+look them over to make sure they read well.
 
 The real joy of using bigtop is the ease of generating running code
 that you might never have to manually edit.  This is the result of
 each method block in the controller block.  They take this form:
 
-    controller Name {
+    controller Name is type {
         ...
         method name is type { ... }
     }
 
-The name can be anything, but for gantry handlers, it must start with do_.
-The type is governed by the backend.  Bigtop::Control::Gantry recognizes
-four types: main_listing, AutoCRUD_form, CRUD_form, and stub.
+The name can be anything, but for Gantry handlers, it must start with do_.
+The type is governed by the backend.  Bigtop::Backend::Control::Gantry
+recognizes four types: main_listing, AutoCRUD_form, CRUD_form, and stub.
 
-    controller Status {
+    controller Status is AutoCRUD {
         ...
         method do_main is main_listing {
             title            `Status`;
@@ -882,7 +899,7 @@ four types: main_listing, AutoCRUD_form, CRUD_form, and stub.
             row_options      Edit, Delete;
         }
 
-A main listing is an html table listing all the rows in the underlying
+A main listing is an HTML table listing all the rows in the underlying
 table sorted by the columns that appear in the foreign_display.  This
 is not suitable for complex controllers.  But, for all the tables
 in this app, it is good enough (at least until there are too many rows
@@ -912,9 +929,9 @@ we allow users to edit the row and to delete it.
 
 =back
 
-        method _form is AutoCRUD_form {
+        method form is AutoCRUD_form {
             form_name        status;
-            fields           name, descr;
+            fields           name, description;
             extra_keys
                 legend => `$self->path_info =~ /edit/i ? 'Edit'
                                                        : 'Add'`;
@@ -924,10 +941,10 @@ we allow users to edit the row and to delete it.
 One of my favorite features of gantry (probably because I wrote it) is
 its automated Create, Retrieve, Update, and Delete.  All you have to
 do to get it is use Gantry::Plugins::AutoCRUD and implement a method
-called _form, which returns a specially crafted hash describing the
+called form, which returns a specially crafted hash describing the
 the appearance of the input form along with populating its fields as
-appropriate.  Bigtop::Control::Gantry can generate the proper _form method
-as show here.
+appropriate.  Bigtop::Backend::Control::Gantry can generate the proper
+form method as shown here.
 
 There are three statements in an AutoCRUD_form method block:
 
@@ -946,17 +963,16 @@ a comma separated list of fields that should be included on the form.
 
 =item extra_keys
 
-any extra keys that should be included in the hash _form returns and their
+any extra keys that should be included in the hash form returns and their
 values.  The values will not be modified in any way, simply include valid
 Perl code in backquotes.  Gantry's form.tt surrounds the entry elements
 with a fieldset.  The legend shown here is the legend of that fieldset.
 
 =back
 
-    controller Company {
+    controller Company is AutoCRUD {
         controls_table   my_companies;
         rel_location     company;
-        uses             Gantry::Plugins::AutoCRUD;
         text_description company;
         page_link_label  Companies;
         method do_main is main_listing {
@@ -965,7 +981,7 @@ with a fieldset.  The legend shown here is the legend of that fieldset.
             header_options   Add;
             row_options      Edit, Delete;
         }
-        method _form is AutoCRUD_form {
+        method form is AutoCRUD_form {
             form_name        company;
             all_fields_but   id;
             extra_keys
@@ -976,10 +992,9 @@ with a fieldset.  The legend shown here is the legend of that fieldset.
 While we can list the fields we want in an AutoCRUD_form, we can also
 use all_fields_but and list the fields we don't want.
 
-    controller Customer {
+    controller Customer is AutoCRUD {
         controls_table   customers;
         rel_location     customer;
-        uses             Gantry::Plugins::AutoCRUD;
         text_description customer;
         page_link_label  Customers;
         method do_main is main_listing {
@@ -988,17 +1003,17 @@ use all_fields_but and list the fields we don't want.
             header_options   Add;
             row_options      Edit, Delete;
         }
-        method _form is AutoCRUD_form {
+        method form is AutoCRUD_form {
             form_name        customer;
             all_fields_but   id;
             extra_keys
                 legend     => `$self->path_info =~ /edit/i ? 'Edit' : 'Add'`;
         }
     }
-    controller LineItem {
+    controller LineItem is AutoCRUD {
         controls_table   line_items;
         rel_location     lineitem;
-        uses             Gantry::Plugins::AutoCRUD, Gantry::Plugins::Calendar;
+        uses             Gantry::Plugins::Calendar;
         text_description `line item`;
         page_link_label  `Line Items`;
         method do_main is main_listing {
@@ -1007,7 +1022,7 @@ use all_fields_but and list the fields we don't want.
             header_options   Add;
             row_options      Edit, Delete;
         }
-        method _form is AutoCRUD_form {
+        method form is AutoCRUD_form {
             form_name        line_item;
             all_fields_but   id;
             extra_keys
@@ -1030,19 +1045,20 @@ the html href link text.
 
 =item 2.
 
-Add C<Gantry::Plugins::Calendar> to the uses list for the controller.
+Put C<Gantry::Plugins::Calendar> in the C<uses> list for the controller.
 
 =item 3.
 
-Include javascript in extra_keys in the AutoCRUD_form method block.
-Use the value as shown here, but change C<line_item> to match your form_name.
+Include javascript in C<extra_keys> in the C<AutoCRUD_form> method block.
+Use the value as shown here, but change C<line_item> to match your
+C<form_name>.
 
 =back
 
-    controller Invoice {
+    controller Invoice is AutoCRUD {
         controls_table   invoices;
         rel_location     invoice;
-        uses             Gantry::Plugins::AutoCRUD, Gantry::Plugins::Calendar;
+        uses             Gantry::Plugins::Calendar;
         text_description invoice;
         page_link_label  Invoices;
         method do_tasks is stub {
@@ -1072,7 +1088,7 @@ method must be do_ followed by the lowercase name of the row option.  In
 order for the methods to operate properly, they must know the id of the
 row they will work on.  Include this in an extra_args statement.
 
-        method _form is AutoCRUD_form {
+        method form is AutoCRUD_form {
             form_name        invoice;
             all_fields_but   id;
             extra_keys
@@ -1092,7 +1108,7 @@ to build it.
 
 If you began following along by using
 
-    bigtop --new Apps::Billing
+    bigtop --new Apps::Billing [...]
 
 You can just move into the Apps-Billing directory and type
 
@@ -1103,69 +1119,51 @@ the examples directory of the bigtop distribution) do this instead:
 
     bigtop --create billing.bigtop all
 
-After a few seconds (ok, so bigtop is not speedy), all the files needed
-for your app will be built in the app_dir.  In my case that is
-/home/pcrow/Apps-Billing.  Running ls on that directory shows:
+After a few seconds, all the files needed for your app will be built in
+the app_dir.  In my case that is /home/pcrow/Billing.  Running ls
+on that directory shows:
 
- Build.PL  Changes  docs  html  lib  MANIFEST  MANIFEST.SKIP  README  t
+ Build.PL      MANIFEST.SKIP app.db        html
+ Changes       README        app.server    lib
+ MANIFEST      app.cgi       docs          t
 
 Of course, the README is meaningless and must be changed.  As should the
-pod sections of the generated code in lib.  Further, the tests are only
-for whether the modules compile (think C<use_ok>).
+pod sections of the generated code in lib.  Further, the tests are minimal.
+The check for broken or missing POD, whether the controller modules compile
+(think C<use_ok>), and whether each controllers default page returns status
+200.
 
-But here is what you do get.  In docs there is a file schema.postgres, which
-defines your database.  To build the clean database do this (remember:
-we are using postgres and you will have to supply passwords and change
-user names as needed):
+But here is what you really get.  In docs there is a file schema.sqlite, which
+defines your database.  To build the clean database do this:
 
-    createdb billing -U postgres
-    psql billing -U apache < docs/schema.postgres
+    sqlite app.db < docs/schema.sqlite
 
 This builds the database, including populating the status table.
+Note that bigtop tried to do this during initial building, so you won't
+have to do this unless you don't have sqlite installed (go install it,
+it's worth it) or it has a different name.
 
-Also in docs is httpd.conf.  Depending on your setup, you may be able
-to simply add
+The app is useable at this point, but it doesn't generate PDF invoices.
+To start it, type:
 
-    <Perl>
-        #!/usr/bin/perl
-        use Apache::DBI;
+    ./app.server [ port ]
 
-        use lib '/home/pcrow/Apps-Billing/lib';
-    </Perl>
-    Include /home/pcrow/Apps-Billing/docs/httpd.conf
+By default app.server runs on port 8080, type an alternate port number
+if that isn't suitable.
 
-to your system httpd.conf.  For our development systems we create
-virtual hosts for each app so our modification to the system conf looks more
-like this:
+If you prefer to use Postgres or MySQL at this point, look in the docs
+directory for the schema file for your database.  If it isn't there,
+you need to add:
 
-    <VirtualHost billing.example.com>
-        ServerName    billing.example.com
-        DocumentRoot  /path/to/gantry/template/root
-        CustomLog     /home/pcrow/logs/combined.log combined
-        ErrorLog      /home/pcrow/logs/billing.err
+    SQL Postgres {}
+    SQL MySQL    {}
 
-        <Perl>
-             #!/usr/bin/perl
-             use Apache::DBI;  # must be at the top of the first
-                               # perl block in httpd.conf
+to your config block and re-run bigtop:
 
-             use lib '/home/pcrow/Apps-Billing/lib';
-        </Perl>
+    bigtop docs/billing.bigtop all
 
-        Include       /home/pcrow/Apps-Billing/docs/httpd.conf
-    </VirtualHost>
-
-Make sure that gantry is installed on your system and that its
-root directory (which is the root of its templates) is the DocumentRoot
-of your virtual host (or copy the files from its root dir to the
-docoument root, if you copy be sure to include the css directory).
-Gantry's ./Build install will take of this for you in most cases.
-
-Then, restart Apache and point your browser to:
-
-    http://billing.example.com/billing/company
-
-The app is useable at this point, but it doesn't generate pdf.
+Then build your database as you normally would and check app.server's
+POD for the proper command line flags to control database connectivity.
 
 =head2 What Was Generated
 
@@ -1175,34 +1173,9 @@ all the other pieces that were made by bigtop.
 
 =head3 Templates and Styling
 
-In the html subdirectory, lives wrapper.tt.  This is the skin of
+In the html subdirectory, lives genwrapper.tt.  This is the skin of
 your application.  The default includes a pleasant style sheet and
-navigation links for all your controllers.  If everything is installed
-correctly, and your config root variable includes the html directory
-in its path, your app will be styled.  If not, you will have to adjust
-PerlSetVars and file locations until Apache can find these things:
-
-=over 4
-
-=item wrapper.tt
-
-include a path to its directory in your root config variable
-
-=item gantry's templates
-
-include a path to their directory in your root config variable
-
-=item css directory
-
-include a path to this in your css_root config variable
-
-=item css location
-
-the config variable should be /css
-
-=back
-    
-Finally C<css/default.css> must live in the document root for the server.
+navigation links for all your controllers.
 
 =head3 Code
 
@@ -1267,14 +1240,12 @@ the table name in all caps.  For example customers.pm exports:
 
 Controllers import this and use it to save reading and typing.
 
-Each one of these modules inherits from Gantry::Utils::CDBI, which
-is a Class::DBI::Sweet subclass.  It correctly handles database connections
-in a mod_perl environment for them (provided you use C<Apache::DBI> at the
-TOP of your first <Perl> block, as shown in the confs above).
+Each one of these modules inherits from Gantry::Utils::DBIxClass, which
+is a DBIx::Class subclass.
 
 =back
 
-This concludes the tutorial.  Feel free to add the pdf and task management
+This concludes the tutorial.  Feel free to add the PDF and task management
 pieces to the app.
 
 =head1 Further Reading
